# CommentCreateRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_user_identifier** | **str** | Max length 100 characters | [optional] 
**internal_user_name** | **str** | Max length 100 characters | [optional] 
**detail** | **str** | Max length 1500 characters | 
**topic** | [**CommentTopic**](CommentTopic.md) |  | 
**is_internal** | **bool** | Flag a comment as internal. Internal comments visible to members of authors organisation. Defaults to false if not provided. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

